@@ -266,7 +266,7 @@ start_controller_in_container()
   then
     create_pid_file $!
     JS7_CONTROLLER_PID=$!
-    echo "...JS7 Controller(${JS7_CONTROLLER_ID}) is started with pid=${JS7_CONTROLLER_PID}!"
+    echo "...JS7 Controller(${JS7_CONTROLLER_ID}) is starting with pid=${JS7_CONTROLLER_PID}!"
     wait "${JS7_CONTROLLER_PID}" || JS7_CONTROLLER_EXIT=$?
     restart_container
   fi
@@ -274,7 +274,7 @@ start_controller_in_container()
 
 restart_container()
 {
-  echo "...JS7 Controller terminates with exit code ${JS7_CONTROLLER_EXIT}"
+  echo "...JS7 Controller terminated with exit code ${JS7_CONTROLLER_EXIT}"
   
   rm "${JS7_CONTROLLER_PID_FILE}" >/dev/null 2>/dev/null || true
   
@@ -312,7 +312,7 @@ shutdown_controller()
   fi
   if running
   then
-    echo "...try to terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+    echo "...trying to terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
     http_command POST "{\"TYPE\": \"ShutDown\"}"
   else
     echo "...not started!"
@@ -337,7 +337,7 @@ shutdown_controller()
       if [ "${JS7_CONTROLLER_STOP_TIMEOUT}" -gt "-1" ] && [ "${loop_counter}" -ge "${JS7_CONTROLLER_STOP_TIMEOUT}" ]
       then
       	echo "..timeout reached"
-      	echo "...try to kill (SIGKILL) the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+      	echo "...trying to cancel (SIGKILL) the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
       	no_mercy "${JS7_CONTROLLER_PID}" || kill_err=$?
       	if [ "$kill_err" = "0" ]
       	then
@@ -361,7 +361,7 @@ abort_controller()
   fi
   if running
   then
-    echo "...try to forcibly terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+    echo "...trying to forcibly terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
     http_command POST "{\"TYPE\": \"EmergencyStop\"}" 2>/dev/null
   else
     echo "...not started!"
@@ -373,7 +373,7 @@ abort_controller()
   sleep 2
   if running
   then
-    echo "...could not terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}!"
+    echo "...could not forcibly terminate the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}!"
     exit ${JS7_CONTROLLER_EXIT}
   else
     JS7_CONTROLLER_EXIT=0
@@ -404,7 +404,7 @@ cancel_controller()
     #if ps -p "${JS7_CONTROLLER_PID}" > /dev/null 2>&1
     #then
     #  echo "...try once more with SIGKILL."
-      echo "...try to cancel (SIGKILL) the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+      echo "...trying to cancel (SIGKILL) the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
       no_mercy "${JS7_CONTROLLER_PID}"
     #else
     #  echo "...killed!"
@@ -422,11 +422,11 @@ no_mercy()
   kill -9 "$1" || kill_err=$?
   if [ "$kill_err" = "0" ]
   then
-    echo "...canceled!"
+    echo "...cancelled!"
     remove_pid_file
     exit 0
   else
-    echo "...could not cancel the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=$1!"
+    echo "...could not cancel (SIGKILL) the JS7 Controller(${JS7_CONTROLLER_ID}) with pid=$1!"
     exit 3
   fi
 }
@@ -435,7 +435,7 @@ switch_over()
 {
   if running
   then
-    echo "...try to switch over the Controller cluster of JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+    echo "...trying to switch-over the Controller cluster of JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
     http_command POST "{\"TYPE\": \"ClusterSwitchOver\"}"
   else
     echo "...not started!"
@@ -446,7 +446,7 @@ take_snapshot()
 {
   if running
   then
-    echo "...try to take a jounal snapshot of JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
+    echo "...trying to take a jounal snapshot of JS7 Controller(${JS7_CONTROLLER_ID}) with pid=${JS7_CONTROLLER_PID}."
     http_command POST "{\"TYPE\": \"TakeSnapshot\"}"
   else
     echo "...not started!"
@@ -909,6 +909,7 @@ test -z "${JS7_CONTROLLER_JAVA_OPTIONS}" && JS7_CONTROLLER_JAVA_OPTIONS="${JAVA_
 echo "${JS7_CONTROLLER_JAVA_OPTIONS}" | grep -e "-Xmx" >/dev/null 2>/dev/null || JS7_CONTROLLER_JAVA_OPTIONS="${JS7_CONTROLLER_JAVA_OPTIONS} -Xmx500m"
 echo "${JS7_CONTROLLER_JAVA_OPTIONS}" | grep -e "-Dfile.encoding" >/dev/null 2>/dev/null || JS7_CONTROLLER_JAVA_OPTIONS="${JS7_CONTROLLER_JAVA_OPTIONS} -Dfile.encoding=UTF-8"
 echo "${JS7_CONTROLLER_JAVA_OPTIONS}" | grep -e "HeapDumpOnOutOfMemoryError" >/dev/null 2>/dev/null || JS7_CONTROLLER_JAVA_OPTIONS="${JS7_CONTROLLER_JAVA_OPTIONS} -XX:+HeapDumpOnOutOfMemoryError"
+echo "${JS7_CONTROLLER_JAVA_OPTIONS}" | grep -e "ExitOnOutOfMemoryError" >/dev/null 2>/dev/null || JS7_CONTROLLER_JAVA_OPTIONS="${JS7_CONTROLLER_JAVA_OPTIONS} -XX:+ExitOnOutOfMemoryError"
 
 
 ##########################
